from django.shortcuts import render, redirect
from django.contrib.auth.decorators import permission_required
from django.utils import timezone
from . import models


def blog_list(request):
    articles = models.Article.objects.filter(published=True).order_by("-date_published")
    return render(request, "blog/blog_list.html", {
        "articles": articles,
    })


def blog_item(request, slug):
    objects = models.Article.objects.filter(slug=slug)
    if not objects.exists():
        return redirect("blog:blog_list")
    return render(request, "blog/blog_item.html",  {
        "article": objects.get()
    })


@permission_required("blog.change_article")
def blog_item_edit(request, slug):
    objects = models.Article.objects.filter(slug=slug)
    if not objects.exists():
        return redirect("blog:blog_list")
    article = objects.get()
    if request.method == "POST":
        article.content = request.POST["content"]
        article.save()
    return render(request, "blog/blog_item_edit.html",  {
        "article": article
    })


def feed(request):
    articles = models.Article.objects.filter(published=True, external=False).order_by("-date_published")
    if articles:
        pubdate = articles[0].date_published
    else:
        pubdate = timezone.now()
    return render(request, "blog/feed.xml", {
        "articles": articles,
        "pubdate": pubdate,
    }, content_type="text/xml")


def blog_item_by_id(request, pid):
    objects = models.Article.objects.filter(id=int(pid))
    if not objects.exists():
        return redirect("blog:blog_list")
    return redirect("blog:blog_item", slug=objects.get().slug)