from django.contrib import sitemaps
from django.urls import reverse
from blog import models as blog_models


class StaticViewSitemap(sitemaps.Sitemap):
    changefreq = "monthly"
    protocol = "https"

    def items(self):
        return [
            "/",
            "blog:blog_list",
            # "orgapy:about",
            # "topopartner:home",
            # "geolist:landing",
        ]
    
    def priority(self, item):
        if item == "/":
            return 1
        return 0.5
    
    def location(self, item):
        if item == "/":
            return "/"
        return reverse(item)


class BlogSitemap(sitemaps.Sitemap):
    changefreq = "monthly"
    protocol = "https"
    priority = 0.5

    def items(self):
        return blog_models.Article.objects.filter(external=False, published=True)

    def lastmod(self, obj):
        return obj.date_published

    def location(self, obj):
        return obj.get_absolute_url()


def get_sitemaps():
    return {
        "static": StaticViewSitemap,
        "blog": BlogSitemap,
    }
